/* to compile on Data General AViiON (DG/UX 5.4.2r01) */

#ifdef __DGUX__
#define signed int
#endif

/* These are really included so that I can use gcc -Wall and not see
 * warnings that these are undefined.  If your system has function
 * prototypes, this is unneeded.
 */

#if !defined(__NetBSD__) && !defined(linux)
#ifdef __GNUC__
/* These do not seem to be needed with gcc-2.5.0.  In fact, having
 * them declared causes errors.
 */

/* __GNUC_MINOR__ was added in gcc starting at 2.5.0.  In versions before
 * this, these needs to be prototyped.  For gcc 2.5.x, these are either
 * built in, or defined in the fixed header files.
 */
#if (!defined(__GNUC_MINOR__) || (__GNUC_MINOR__ >= 6)) && !defined(SOLARIS2)
void    printf(char* , ...);
void    puts(char *);
void    fprintf(FILE*, char *, ...);
int sscanf(char *, ...);
#endif

int     sleep(unsigned);
int     atoi(char *);
int	gethostname(char *, int);
#if !defined(SOLARIS2)
char 	*strcat(char *, char*);
char	*strchr(char*, char);
#endif
#endif
#endif

#if defined(__pyrsoft)
char *strchr(char *, char);
#endif

